#define UTS_MACHINE		"aarch64"
#define LINUX_COMPILE_BY	""
#define LINUX_COMPILE_HOST	"797be4b0849a"
#define LINUX_COMPILER		"aarch64-xilinx-linux-gcc (GCC) 12.2.0, GNU ld (GNU Binutils) 2.39.0.20220819"
